@@ -32,19 +32,19 @@ const Gtk = imports.gi.Gtk;
 const GLib = imports.gi.GLib;
 const Tracker = imports.gi.Tracker;
 
-const Categories = imports.categories;
 const ChangeMonitor = imports.changeMonitor;
 const Documents = imports.documents;
 const Error = imports.error;
-const FilterController = imports.filterController;
 const Format = imports.format;
 const Global = imports.global;
 const Main = imports.main;
 const MainWindow = imports.mainWindow;
+const Manager = imports.manager;
 const OffsetController = imports.offsetController;
 const Path = imports.path;
 const Query = imports.query;
-const SelectionController = imports.selectionController;
+const Searchbar = imports.searchbar;
+const Selections = imports.selections;
 const Sources = imports.sources;
 const TrackerController = imports.trackerController;
 const Tweener = imports.util.tweener;
@@ -108,17 +108,10 @@ Application.prototype = {
         EvDoc.init();
         Tweener.init();
 
-        let provider = new Gtk.CssProvider();
-        provider.load_from_path(Path.STYLE_DIR + "gtk-style.css");
-        Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
-                                                 provider,
-                                                 600);
-
         Global.application = this;
         Global.settings = new Gio.Settings({ schema: 'org.gnome.documents' });
         Global.offsetController = new OffsetController.OffsetController();
-        Global.filterController = new FilterController.FilterController();
-        Global.categoryManager = new Categories.CategoryManager();
+        Global.searchController = new Searchbar.SearchController();
         Global.errorHandler = new Error.ErrorHandler();
 
         // connect to tracker
@@ -140,14 +133,18 @@ Application.prototype = {
                             this.quit();
                         }
 
+                        Global.connectionQueue = new TrackerController.TrackerConnectionQueue();
                         Global.sourceManager = new Sources.SourceManager();
-                        Global.selectionController = new SelectionController.SelectionController();
+                        Global.searchCategoryManager = new Searchbar.SearchCategoryManager();
+                        Global.searchMatchManager = new Searchbar.SearchMatchManager();
+                        Global.searchTypeManager = new Searchbar.SearchTypeManager();
                         Global.queryBuilder = new Query.QueryBuilder();
                         Global.changeMonitor = new ChangeMonitor.TrackerChangeMonitor();
+                        Global.collectionManager = new Manager.BaseManager();
                         Global.documentManager = new Documents.DocumentManager();
                         Global.trackerController = new TrackerController.TrackerController();
+                        Global.selectionController = new Selections.SelectionController();
                         Global.modeController = new WindowMode.ModeController();
-                        Global.focusController = new WindowMode.FocusController();
 
                         this._mainWindow = new MainWindow.MainWindow();
                         this.activate();
