@@ -25,7 +25,7 @@
 #include "gd-gdata-miner.h"
 
 #define BUS_NAME "org.gnome.Documents.GDataMiner"
-#define AUTOQUIT_TIMEOUT 5
+#define AUTOQUIT_TIMEOUT 5 /* seconds */
 
 static const gchar introspection_xml[] =
   "<node>"
@@ -39,6 +39,43 @@ static GDBusNodeInfo *introspection_data = NULL;
 static GCancellable *cancellable = NULL;
 static GMainLoop *loop = NULL;
 static guint name_owner_id = 0;
+static guint autoquit_id = 0;
+static gboolean refreshing = FALSE;
+
+static gboolean
+autoquit_timeout_cb (gpointer _unused)
+{
+  g_debug ("Timeout reached, quitting...");
+
+  autoquit_id = 0;
+  g_main_loop_quit (loop);
+
+  return FALSE;
+}
+
+static void
+ensure_autoquit_off (void)
+{
+  if (g_getenv ("GDATA_MINER_PERSIST") != NULL)
+    return;
+
+  if (autoquit_id != 0)
+    {
+      g_source_remove (autoquit_id);
+      autoquit_id = 0;
+    }
+}
+
+static void
+ensure_autoquit_on (void)
+{
+  if (g_getenv ("GDATA_MINER_PERSIST") != NULL)
+    return;
+
+  autoquit_id = 
+    g_timeout_add_seconds (AUTOQUIT_TIMEOUT,
+                           autoquit_timeout_cb, NULL);
+}
 
 static gboolean
 signal_handler_cb (gpointer user_data)
@@ -63,6 +100,9 @@ miner_refresh_db_ready_cb (GObject *source,
 
   gd_gdata_miner_refresh_db_finish (GD_GDATA_MINER (source), res, &error);
 
+  refreshing = FALSE;
+  ensure_autoquit_on ();
+
   if (error != NULL)
     {
       g_printerr ("Failed to refresh the DB cache: %s\n", error->message);
@@ -72,9 +112,6 @@ miner_refresh_db_ready_cb (GObject *source,
     {
       g_dbus_method_invocation_return_value (invocation, NULL);
     }
-
-  g_object_unref (cancellable);
-  g_main_loop_quit (loop);
 }
 
 static void
@@ -82,6 +119,13 @@ handle_refresh_db (GDBusMethodInvocation *invocation)
 {
   GdGDataMiner *miner;
 
+  ensure_autoquit_off ();
+
+  /* if we're refreshing already, compress with the current request */
+  if (refreshing)
+    return;
+
+  refreshing = TRUE;
   cancellable = g_cancellable_new ();
   miner = gd_gdata_miner_new ();
 
@@ -169,6 +213,8 @@ main (int argc,
       char **argv)
 {
   g_type_init ();
+
+  ensure_autoquit_on ();
   loop = g_main_loop_new (NULL, FALSE);
 
   g_unix_signal_add_full (G_PRIORITY_DEFAULT,
@@ -185,8 +231,7 @@ main (int argc,
 
   name_owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
                                   BUS_NAME,
-                                  G_BUS_NAME_OWNER_FLAGS_ALLOW_REPLACEMENT |
-                                  G_BUS_NAME_OWNER_FLAGS_REPLACE,
+                                  G_BUS_NAME_OWNER_FLAGS_NONE,
                                   on_bus_acquired,
                                   on_name_acquired,
                                   on_name_lost,
